@@ -338,20 +338,11 @@ class EntityConfiguration:
             target[ec.payload["sub"]] = ec
 
         for ahints in authority_hints:
-            ec = target.get(ahints)
-            if not ec:
+            if not self.verified_superiors.get(ahints, None):
                 logger.warning(
                     f"{ahints} is not available, missing or not valid authority hint"
                 )
                 continue
-            # TODO: this is a copy/pasted code with the previous for statement
-            # TODO: it must be generalized and merged with the previous one
-            if ec.validate_by_itself():
-                target = self.verified_superiors
-            else:
-                target = self.failed_superiors
-
-            target[ec.payload["sub"]] = ec
 
         return self.verified_superiors
 
@@ -428,11 +419,11 @@ class EntityConfiguration:
             try:
                 # get superior fetch url
                 fetch_api_url = ec.payload["metadata"]["federation_entity"][
-                    "federation_api_endpoint"
+                    "federation_fetch_endpoint"
                 ]
             except KeyError:
                 logger.warning(
-                    "Missing federation_api_endpoint in  "
+                    "Missing federation_fetch_endpoint in  "
                     f"federation_entity metadata for {self.sub} by {ec.sub}."
                 )
                 self.invalid_superiors[ec.sub] = None
