@@ -6,6 +6,7 @@ from spid_cie_oidc.entity.schemas.op_metadata import (
     OPMetadataSpid
 )
 from spid_cie_oidc.onboarding.schemas.authn_requests import (
+    AcrValues,
     AuthenticationRequestCie,
     AuthenticationRequestSpid
 )
@@ -13,6 +14,7 @@ from spid_cie_oidc.onboarding.schemas.introspection_request import Introspection
 from spid_cie_oidc.onboarding.schemas.revocation_request import RevocationRequest
 from spid_cie_oidc.onboarding.schemas.token_requests import TokenAuthnCodeRequest, TokenRefreshRequest
 
+
 OIDCFED_PROVIDER_PROFILES_MEDIA = getattr(
     settings,
     "OIDCFED_PROVIDER_PROFILES_MEDIA",
@@ -21,7 +23,7 @@ OIDCFED_PROVIDER_PROFILES_MEDIA = getattr(
             "logo": "svg/spid-logo-c-lb.svg"
         },
         "cie": {
-            "logo": "images/logo-cie-png"
+            "logo": "images/logo-cie.png"
         },
     },
 )
@@ -103,10 +105,10 @@ OIDCFED_PROVIDER_PROFILES = getattr(
 )
 
 OIDCFED_PROVIDER_SALT = getattr(settings, "OIDCFED_PROVIDER_SALT", "CHANGEME")
-
 OIDCFED_DEFAULT_PROVIDER_PROFILE = getattr(settings, "OIDCFED_PROVIDER_PROFILE", "spid")
 
-OIDCFED_PROVIDER_MAX_REFRESH = 1
+OIDCFED_PROVIDER_MAX_REFRESH = getattr(settings, "OIDCFED_PROVIDER_MAX_REFRESH", 1)
+OIDCFED_PROVIDER_HISTORY_PER_PAGE = getattr(settings, "OIDCFED_PROVIDER_HISTORY_PER_PAGE", 50)
 
 # lifetime of validity of an auth code
 OIDCFED_PROVIDER_AUTH_CODE_MAX_AGE = getattr(
@@ -115,6 +117,26 @@ OIDCFED_PROVIDER_AUTH_CODE_MAX_AGE = getattr(
     10
 )
 
+
+OIDCFED_PROVIDER_PROFILES_DEFAULT_ACR = getattr(
+    settings,
+    "OIDCFED_PROVIDER_PROFILES_DEFAULT_ACR",
+    dict(
+        spid = AcrValues.l2.value,
+        cie = AcrValues.l2.value
+    )
+)
+
+OIDCFED_PROVIDER_PROFILES_ACR_4_REFRESH = getattr(
+    settings,
+    "OIDCFED_PROVIDER_PROFILES_ACR_4_REFRESH",
+    dict(
+        spid = [AcrValues.l1.value],
+        cie = [AcrValues.l1.value]
+    )
+)
+
+
 OIDCFED_ATTRNAME_I18N = {
     # SPID
     "https://attributes.spid.gov.it/name": _("Name"),
