@@ -2,10 +2,10 @@ from copy import deepcopy
 from django.contrib.auth import get_user_model
 from django.test import Client, TestCase, override_settings
 from django.urls import reverse
-from spid_cie_oidc.authority.tests.settings import RP_METADATA, rp_onboarding_data, RP_METADATA_JWK1
+from spid_cie_oidc.authority.tests.settings import RP_METADATA, RP_METADATA_JWK1, rp_onboarding_data
 from django.utils import timezone
 
-from spid_cie_oidc.entity.jwtse import create_jws, unpad_jwt_payload
+from spid_cie_oidc.entity.jwtse import create_jws, unpad_jwt_payload, verify_jws
 from spid_cie_oidc.entity.models import (
     FederationEntityConfiguration,
     FetchedEntityStatement,
@@ -14,7 +14,7 @@ from spid_cie_oidc.entity.models import (
 from spid_cie_oidc.entity.tests.settings import TA_SUB
 from spid_cie_oidc.entity.utils import datetime_from_timestamp, exp_from_now, iat_now
 from spid_cie_oidc.provider.models import IssuedToken, OidcSession
-from spid_cie_oidc.provider.tests.settings import op_conf
+from spid_cie_oidc.provider.tests.settings import op_conf, op_conf_priv_jwk
 from spid_cie_oidc.relying_party.utils import random_string
 
 RP_SUB = rp_onboarding_data["sub"]
@@ -69,9 +69,8 @@ class AuthnRequestTest(TestCase):
         )
         self.trust_chain = TrustChain.objects.create(
             sub=RP_SUB,
-            type="openid_relying_party",
             exp=datetime_from_timestamp(exp_from_now(33)),
-            metadata=RP_METADATA["openid_relying_party"],
+            metadata=RP_METADATA,
             status="valid",
             trust_anchor=self.ta_fes,
             is_active=True,
@@ -108,6 +107,7 @@ class AuthnRequestTest(TestCase):
         self.assertFalse("error" in res.content.decode())
         res = client.post(consent_page_url, {"agree": True})
         issued_token = IssuedToken.objects.all().first()
+        verify_jws(issued_token.id_token, op_conf_priv_jwk)
         id_token = unpad_jwt_payload(issued_token.id_token)
         self.assertEqual(id_token.get("family_name"), "rossi")
         self.assertEqual(id_token.get("email"), "test@test.it")
@@ -270,7 +270,7 @@ class AuthnRequestTest(TestCase):
     @override_settings(OIDCFED_DEFAULT_TRUST_ANCHOR=TA_SUB)
     def test_auth_request_invalid_jwk(self):
         jws = create_jws(self.REQUEST_OBJECT_PAYLOAD, RP_METADATA_JWK1)
-        self.trust_chain.metadata["jwks"]["keys"][0][
+        self.trust_chain.metadata['openid_relying_party']["jwks"]["keys"][0][
             "kid"
         ] = "31ALfVXx9dcAMMHCVvh42qLTlanBL_r6BTnD5uMDzFT"
         self.trust_chain.save()
@@ -280,7 +280,7 @@ class AuthnRequestTest(TestCase):
         self.assertTrue(res.status_code == 302)
         self.assertIn("error=invalid_request", res.url)
         self.assertIn("state", res.url)
-        self.trust_chain.metadata["jwks"]["keys"][0][
+        self.trust_chain.metadata['openid_relying_party']["jwks"]["keys"][0][
             "kid"
         ] = RP_METADATA_JWK1['kid']
         self.trust_chain.save()
