@@ -42,9 +42,8 @@ class RefreshTokenTest(TestCase):
         )
         self.trust_chain = TrustChain.objects.create(
             sub=RP_SUB,
-            type="openid_relying_party",
             exp=datetime_from_timestamp(exp_from_now(33)),
-            metadata=RP_METADATA["openid_relying_party"],
+            metadata=RP_METADATA,
             status="valid",
             trust_anchor=self.ta_fes,
             is_active=True,
@@ -77,7 +76,7 @@ class RefreshTokenTest(TestCase):
         )
         IssuedToken.objects.create(
             access_token = create_jws(self.refresh_token, op_conf_priv_jwk),
-            refresh_token = self.refresh_token,
+            refresh_token = create_jws(self.refresh_token, op_conf_priv_jwk),
             session = session,
             expires = timezone.localtime()
         )
