@@ -13,6 +13,7 @@ from django.utils.decorators import method_decorator
 from django.views import View
 from django.views.decorators.csrf import csrf_exempt
 from spid_cie_oidc.entity.jwtse import unpad_jwt_payload
+from spid_cie_oidc.provider.exceptions import ValidationException
 from spid_cie_oidc.provider.models import IssuedToken, OidcSession
 
 from . import OpBase
@@ -31,9 +32,13 @@ class TokenEndpoint(OpBase, View):
         """
         # PKCE check - based on authz.authz_request["code_challenge_method"] == S256
         code_challenge = hashlib.sha256(request.POST["code_verifier"].encode()).digest()
-        code_challenge = base64.urlsafe_b64encode(code_challenge).decode("utf-8")
-        code_challenge = code_challenge.replace("=", "")
-        if code_challenge != self.authz.authz_request["code_challenge"]:
+        code_challenge_b64 = base64.urlsafe_b64encode(code_challenge).decode("utf-8")
+        code_challenge_unpad = code_challenge_b64.replace("=", "")
+        if code_challenge_unpad != self.authz.authz_request["code_challenge"]:
+            logger.warning(
+                f"PCKE validation failed. Produced code challenge [{code_challenge_unpad}]"
+                f" if different from which sent by RP [{self.authz.authz_request['code_challenge']}]"
+            )
             return HttpResponseForbidden()
         #
 
@@ -127,14 +132,20 @@ class TokenEndpoint(OpBase, View):
 
     def post(self, request, *args, **kwargs):
         logger.debug(f"{request.headers}: {request.POST}")
-
-        result = self.validate_json_schema(
-            request.POST.dict(),
-            request.POST["grant_type"],
-            "Token request object validation failed "
-        )
-        if result:
-            return result
+        try:
+            self.validate_json_schema(
+                request.POST.dict(),
+                request.POST["grant_type"],
+                "Token request object validation failed "
+            )
+        except ValidationException:
+            return JsonResponse(
+                {
+                    "error": "invalid_request",
+                    "error_description": "Token request object validation failed",
+                },
+                status = 400
+            )
 
         self.commons = self.get_jwt_common_data()
         self.issuer = self.get_issuer()
@@ -153,8 +164,12 @@ class TokenEndpoint(OpBase, View):
                 request.POST['client_id'],
                 request.POST['client_assertion']
             )
-        except Exception:
+        except Exception as e:
             # TODO: coverage test
+            logger.warning(
+                "Client authentication failed for "
+                f"{request.POST.get('client_id', 'unknow')}: {e}"
+            )
             return JsonResponse(
                 # TODO: error message here
                 {
