@@ -59,7 +59,7 @@ class RpCallBack(TestCase):
         )
 
     @override_settings(HTTP_CLIENT_SYNC=True)
-    @patch("spid_cie_oidc.relying_party.views.process_user_attributes", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.process_user_attributes", return_value=None)
     @patch("requests.post", return_value=MockedTokenEndPointResponse())
     @patch("requests.get", return_value=MockedUserInfoResponse())
     def test_rp_callback_no_rp_attr_map(self, mocked, mocked_2, mocked_3):
@@ -69,7 +69,7 @@ class RpCallBack(TestCase):
         self.assertTrue(res.status_code == 403)
 
     @override_settings(HTTP_CLIENT_SYNC=True)
-    @patch("spid_cie_oidc.relying_party.views.process_user_attributes", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.process_user_attributes", return_value=None)
     @patch("requests.post", return_value=MockedTokenEndPointResponse())
     @patch("requests.get", return_value=MockedUserInfoResponse())
     def test_rp_callback_incorret_request(self, mocked, mocked_2, mocked_3):
@@ -79,9 +79,9 @@ class RpCallBack(TestCase):
         self.assertTrue("error" in res.json())
 
     @override_settings(HTTP_CLIENT_SYNC=True)
-    @patch("spid_cie_oidc.relying_party.views.process_user_attributes", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.process_user_attributes", return_value=None)
     @patch("requests.post", return_value=MockedTokenEndPointResponse())
-    @patch("spid_cie_oidc.relying_party.views.SpidCieOidcRpCallbackView.get_userinfo", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.SpidCieOidcRpCallbackView.get_userinfo", return_value=None)
     def test_rp_callback_no_userinfo(self, mocked, mocked_2, mocked_3):
         client = Client()
         url = reverse("spid_cie_rp_callback")
@@ -89,11 +89,34 @@ class RpCallBack(TestCase):
         self.assertTrue(res.status_code == 400)
         
     @override_settings(HTTP_CLIENT_SYNC=True)
-    @patch("spid_cie_oidc.relying_party.views.process_user_attributes", return_value=None)
-    @patch("spid_cie_oidc.relying_party.views.SpidCieOidcRpCallbackView.access_token_request", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.process_user_attributes", return_value=None)
+    @patch("spid_cie_oidc.relying_party.views.rp_callback.SpidCieOidcRpCallbackView.access_token_request", return_value=None)
     def test_rp_callback_no_token_response(self, mocked, mocked_2):
         client = Client()
         url = reverse("spid_cie_rp_callback")
         res = client.get(url, {"state": STATE, "code": CODE})
         self.assertTrue(res.status_code == 400)
         self.assertTrue("invalid token response" in res.content.decode())
+
+    @override_settings(HTTP_CLIENT_SYNC=True)
+    @patch("requests.post", return_value=MockedTokenEndPointResponse())
+    @patch("requests.get", return_value=MockedUserInfoResponse())
+    def test_rp_callback_no_rp_conf(self, mocked, mocked_2):
+        FederationEntityConfiguration.objects.filter(
+            sub = self.rp_config["sub"]
+        ).delete()
+        client = Client()
+        url = reverse("spid_cie_rp_callback")
+        res = client.get(url, {"state": STATE, "code": CODE})
+        self.assertTrue("Relay party not found" in res.content.decode())
+
+
+    @override_settings(HTTP_CLIENT_SYNC=True)
+    @patch("requests.post", return_value=MockedTokenEndPointResponse())
+    @patch("requests.get", return_value=MockedUserInfoResponse())
+    def test_rp_callback_no_authz(self, mocked, mocked_2):
+        OidcAuthentication.objects.all().delete()
+        client = Client()
+        url = reverse("spid_cie_rp_callback")
+        res = client.get(url, {"state": STATE, "code": CODE})
+        self.assertTrue("Authentication not found" in res.content.decode())
